<?php

function basique_setup()
{
	if ( ! isset( $content_width ) ) {
		$content_width = 1024;
	}
	add_theme_support( 'title-tag' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'html5' );
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );
	/* Later Support
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
		'gallery',
		'status',
		'audio',
		'chat',
	) );
	*/
	add_post_type_support( 'page', 'excerpt' );
	add_theme_support( 'custom-logo' );
	add_theme_support( 'custom-logo', array(
		'height'      => 92,
		'width'       => 92,
		'flex-height' => true,
		'flex-width'  => true,
		'header-text' => array(),
	) );
	add_theme_support( 'custom-background' );
	add_theme_support( 'custom-background', array(
		'default-color' => 'ffffff',
	) );
	add_theme_support( 'custom-header' );
	add_theme_support( 'custom-header', array(
		'default-image'          => '',
		'width'                  => 2880,
		'height'                 => 92,
		'flex-height'            => true,
		'flex-width'             => true,
		'uploads'                => true,
		'random-default'         => false,
		'header-text'            => false,
		'default-text-color'     => '',
		'wp-head-callback'       => '',
		'admin-head-callback'    => '',
		'admin-preview-callback' => '',
	) );


	register_nav_menus(
		array(
			'header-menu' => __( 'Header Menu', 'basique' ),
			'footer-menu' => __( 'Footer Menu', 'basique')
		)
	);

	add_editor_style( array( 'assets/editor-style.css' ) );

	$starter_content = apply_filters( 'basique_starter_content', array(
		'widgets' => array(
			'header-widget-area' => array(
				'search',
			),
			/*
			Later Support
			'sidebar-widget-area' => array(
				'',
			),
			*/
			'footer-widget-area' => array(
				'',
			),
		),
	) );
	add_theme_support( 'starter-content', $starter_content );

	add_image_size( 'basique-large', 1920, 1200, false );
	add_image_size( 'basique-content', 800, 500, false );
	add_image_size( 'basique-logo', 92, 92, false );
}
add_action( 'after_setup_theme', 'basique_setup' );





function basique_tagcount_filter ($variable)
{
	$variable = str_replace( '<span class="tag-link-count"> (', '<span class="tag-link-count">&bull;', $variable );
	$variable = str_replace( ')</span>', '</span>', $variable );
	return $variable;
}
add_filter('wp_tag_cloud','basique_tagcount_filter');




// Customize Search Form
function basique_search_form( $form )
{
	$form = '<form role="search" method="get" class="search-form" action="' . home_url( '/' ) . '" >
	<label class="screen-reader-text" for="s">' . __( '',  'basique' ) . '</label>
	<input type="search" value="' . get_search_query() . '" name="s" id="search" placeholder="Search" />' . '<input type="submit" id="searchsubmit" value="' . esc_attr__( 'Search', 'basique' ) . '" />
	</form>';
	return $form;
}
add_filter( 'get_search_form', 'basique_search_form' );




add_filter( 'the_title', 'basique_title' );
function basique_title( $title )
{
	if ( $title == '' ) {
		return '&rarr;';
	} else {
		return $title;
	}
}





add_action( 'after_setup_theme', function ( $buffer )
{
	function basique_strip_buffer( $buffer )
	{
		$buffer = preg_replace( '/<!--(.|s)*?-->/', '', $buffer );
		return $buffer;
	}
	function basique_buffer_start()
	{
		ob_start( "basique_strip_buffer" );
	}
	function basique_buffer_end()
	{
		ob_end_flush();
	}
	add_action('get_header', 'basique_buffer_start');
	add_action('wp_footer', 'basique_buffer_end');
} );

add_filter( 'the_content', 'escape_code_fragments' );
add_filter( 'pre_comment_content', 'escape_code_fragments' );
function escape_code_fragments( $source ) { $encoded = preg_replace_callback( '/<code(.*?)>(.*?)<\/code>/ims', create_function (
	'$matches',
	'$matches[2] = preg_replace( array("/^[\r|\n]+/i", "/[\r|\n]+$/i"), "", $matches[2] ); return "<code" . $matches[1] . ">" . esc_html( $matches[2] ) . "</code>";' ), $source );

if ($encoded) {
	return $encoded;
} else {
	return $source;
}
}


function _remove_script_version( $src ){
	$parts = explode( '?', $src );
	return $parts[0];
}
add_filter( 'script_loader_src', '_remove_script_version', 15, 1 );
add_filter( 'style_loader_src', '_remove_script_version', 15, 1 );


add_action( 'wp_enqueue_scripts', 'basique_load_scripts' );
function basique_load_scripts()
{
	wp_enqueue_style( 'style', get_stylesheet_uri() );
	wp_enqueue_style( 'font', get_template_directory_uri() . '/assets/css/fonts.css' );
	wp_enqueue_script ( 'act', get_template_directory_uri() . '/assets/js/act.js' );

	function basique_optimize_scripts( $tag, $handle )
	{
		$scripts_to_optimize = array(
			'act'
		);
		foreach( $scripts_to_optimize as $basique_script )
		{
			if ( $basique_script === $handle )
			{
				return str_replace( 'src', 'defer src', $tag );
			}
		}
		return $tag;
	}
	add_filter('script_loader_tag', 'basique_optimize_scripts', 10, 2);
}


// Register Widget Areas
add_action( 'widgets_init', 'basique_widgets_init' );
function basique_widgets_init()
{
	// Primary - Widget Area
	register_sidebar( array (
		'name' => __( 'Header Widget Area', 'basique' ),
		'id' => 'header-widget-area',
		'description' => 'Add widgets in this area to display them on header area.',
		'before_widget' => '<div id="widget-%1$s" class="widget-container %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h6 class="widget-title">',
		'after_title' => '</h6>',
	) );
	// Secondary - Widget Area
	/*
	register_sidebar( array (
		'name' => __( 'Sidebar Widget Area', 'basique' ),
		'id' => 'sidebar-widget-area',
		'description' => 'Add widgets in this area to display them on sidebar area.',
		'before_widget' => '<div id="widget-%1$s" class="widget-container %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h6 class="widget-title">',
		'after_title' => '</h6>',
	) );*/
	// Footer - Widget Area
	register_sidebar( array (
		'name' => __( 'Footer Widget Area', 'basique' ),
		'id' => 'footer-widget-area',
		'description' => 'Add widgets in this area to display them on footer area.',
		'before_widget' => '<div id="widget-%1$s" class="widget-container %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h6 class="widget-title">',
		'after_title' => '</h6>',
	) );
}


// Reply Comment Form
add_action( 'comment_form_before', 'basique_enqueue_comment_reply_script' );
function basique_enqueue_comment_reply_script() {
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
function basique_custom_pings( $comment ) {
	$GLOBALS['comment'] = $comment;
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>"><?php echo comment_author_link(); ?></li>
	<?php
}


add_action( 'init', function() {
	remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
	remove_action( 'admin_print_styles', 'print_emoji_styles' );
	remove_filter( 'comment_text_rss', 'wp_staticize_emoji' );
	remove_action( 'embed_head', 'print_emoji_detection_script' );
	remove_filter( 'oembed_dataparse', 'wp_filter_oembed_result', 10 );
	remove_action( 'rest_api_init', 'wp_oembed_register_route' );
	remove_filter( 'the_content_feed', '_oembed_filter_feed_content' );
	remove_filter( 'the_content_feed', 'wp_staticize_emoji' );
	remove_action( 'wp_head', 'rsd_link' );
	remove_action( 'wp_head', 'wlwmanifest_link' );
	remove_action( 'wp_head', 'wp_generator' );
	remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
	remove_action( 'wp_head', 'wp_oembed_add_discovery_links' );
	remove_action( 'wp_head', 'wp_oembed_add_host_js' );
	remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
	remove_action( 'wp_head', 'wp_resource_hints', 2 );
	remove_filter( 'wp_mail', 'wp_staticize_emoji_for_email' );
	remove_action( 'wp_print_styles', 'print_emoji_styles' );
} );
